##### ΚΕΦΑΛΑΙΟ 12 : ΣΥΓΚΡΙΣΗ ΜΕΤΑΞΥ ΔΥΟ ΔΕΙΓΜΑΤΩΝ

## Α. ΑΝΕΞΑΡΤΗΤΑ ΔΕΙΓΜΑΤΑ

# Διαβάζουμε τα δεδομένα του κεφαλαίου από το αντίστοιχο αρχείο στο πλαίσιο δεδομένων ch12.1
read.table("chapter12_1.Rdata")->ch12.1

# Βασικός έλεγχος του πλαισίου δεδομένων
str(ch12.1)
# Θηκόγραμμα των δεδομένων
plot(ch12.1)
# Περιγραφικά στατιστικά
psych::describe.by(ch12.1$satisfaction,ch12.1$organization)

# Σύγκριση των δύο δειγμάτων
# α) υποθέτοντας ίση διακύμανση
t.test(satisfaction~organization,ch12.1,var.equal=T)
# β) με διόρθωση για άνιση διακύμανση
t.test(satisfaction~organization,ch12.1)

# Υπολογισμός του κριτηρίου από τα δεδομένα
m<-with(ch12.1,aggregate(satisfaction,by=list(organization),mean))[,2]   # μέσοι όροι δειγμάτων
v<-with(ch12.1,aggregate(satisfaction,by=list(organization),var))[,2]    # διακυμάνσεις δειγμάτων
N<-with(ch12.1,aggregate(satisfaction,by=list(organization),length))[,2] # μέγεθος δειγμάτων
se2<-v/N          # τετραγωνικά τυπικά σφάλματα δειγμάτων
se<-sqrt(se2)
sp<-sqrt(sum(v*(N-1))/(sum(N)-2)*(sum(N)/prod(N))) # ενοποιημένο τυπικό σφάλμα
dm<-diff(m)       # διαφορά μέσων όρων
t<-dm/sp          # κριτήριο t
df<-sum(N)-2      # βαθμοί ελευθερίας
p<-2*(1-pt(t,df)) # στατιστική σημαντικότητα για αμφίπλευρο έλεγχο

# Υπολογισμός διαστήματος εμπιστοσύνης 95%
tc<-qt((1-0.05/2),df) # κρίσιμη τιμή κριτηρίου, βάσει κατανομής
ci<-tc*sp             # μονόπλευρο εύρος διαστήματος στην κλίμακα μέτρησης
CI95<-c(dm-ci,dm+ci)  # διάστημα εμπιστοσύνης διαφοράς

# Εικόνα 12.4 -- Σχεδιάγραμμα σφαλμάτων
cim<-tc*se # μονόπλευρο διάστημα εμπιστοσύνης επιμέρους μέσων όρων
plot(m,ylim=c(20.5,28.5),xlab="Είδος Οργανισμού",ylab="95% CI Επαγγελματική Ικανοποίηση",las=1,boxwex=0)
points(m)  # σημεία μέσων όρων
arrows(c(1,2),m$x-cim,c(1,2),m$x+cim,angle=90,code=3,length=0.2) # γραμμές «σφαλμάτων» 

## Β. ΕΞΑΡΤΗΜΕΝΑ ΔΕΙΓΜΑΤΑ

# Διαβάζουμε τα δεδομένα του κεφαλαίου από το αντίστοιχο αρχείο στο πλαίσιο δεδομένων ch12.1
read.table("chapter12_2.Rdata")->ch12.2

# Βασικός έλεγχος του πλαισίου δεδομένων
str(ch12.2)
# Θηκόγραμμα των δεδομένων
boxplot(ch12.2)
# Διάγραμμα σκεδασμού των δεδομένων
plot(ch12.2)
# Περιγραφικά στατιστικά
psych::describe(ch12.2)

# Σύγκριση των δύο εξαρτημένων δειγμάτων
t.test(ch12.2$before,ch12.2$after,paired=T)
# Συσχέτιση μεταξύ των δειγμάτων
cor(ch12.2)

# Υπολογισμός του κριτηρίου από τα δεδομένα
d<-apply(ch12.2,1,diff) # διαφορές μεταξύ εξαρτημένων ζευγών
N<-nrow(ch12.2)         # πλήθος εξαρτημένων ζευγών
s<-sd(d)/sqrt(N)        # τυπικό σφάλμα διαφορών
md<-mean(d)             # μέση διαφορά
t<-md/s                 # κριτήριο t
df<-N-1                 # βαθμοί ελευθερίας
p<-2*(1-pt(t,df))       # στατιστική σημαντικότητα για αμφίπλευρο έλεγχο

# Υπολογισμός διαστήματος εμπιστοσύνης 95%
tc<-qt((1-0.05/2),df) # κρίσιμη τιμή κριτηρίου, βάσει κατανομής
ci<-tc*s              # μονόπλευρο εύρος διαστήματος στην κλίμακα μέτρησης
CI95<-c(md-ci,md+ci)  # διάστημα εμπιστοσύνης διαφοράς

# Εικόνα 12.8 -- Σχεδιάγραμμα σφαλμάτων
m<-apply(ch12.2,2,mean)
plot(c(1,2),m,xlim=c(0.5,2.5),ylim=c(24,51),xlab="Αυτοεικόνα",ylab="95% CI",las=1,type="p",xaxt="n")
axis(side=1,at=c(1,2),labels=c("Πριν θεραπεία","Μετά θεραπεία"))
sd<-apply(ch12.2,2,sd)
ci<-tc*sd/sqrt(N)
arrows(c(1,2),m-ci,c(1,2),m+ci,angle=90,code=3,length=0.2) # γραμμές «σφαλμάτων»  
# το τυπικό σφάλμα του μέσου όρου είναι ακατάλληλο για σύγκριση εξαρτημένων δειγμάτων!

