##### ΚΕΦΑΛΑΙΟ 6 : Η ΚΑΝΟΝΙΚΗ ΚΑΤΑΝΟΜΗ

## ΕΛΕΓΧΟΣ ΕΛΛΕΙΠΟΥΣΩΝ ΤΙΜΩΝ
#
# Διαβάζουμε τα δεδομένα του κεφαλαίου από το αντίστοιχο αρχείο στο πλαίσιο δεδομένων ch6
read.table("chapter6.Rdata")->ch6

# Βασικός έλεγχος του πλαισίου δεδομένων
str(ch6)

# Πίνακες συχνοτήτων των δύο μεταβλητών
table(ch6$performance)
table(ch6$motivation)

# Αφαιρούμε τις δύο «αδύνατες» τιμές (μεγαλύτερες του 9) από τη μεταβλητή performance
# αντικαθιστώντας με ελλείπουσες τιμές (NA)
ch6$performance[ch6$performance>9]<-NA

# Έλεγχος του πλαισίου δεδομένων (εμφανίζονται οι ελλείπουσες τιμές ανά μεταβλητή)
summary(ch6)

# Πλήθος ελλειπουσών τιμών ανά μεταβλητή
apply(apply(ch6,2,is.na),2,sum)
# Ποσοστό (%) ελλειπουσών τιμών ανά μεταβλητή
round(100*apply(apply(ch6,2,is.na),2,sum)/nrow(ch6),1)
# Λίγο πιο απλά, ξεχωριστά η αναλογία για κάθε μεταβλητή
sum(is.na(ch6$performance))/length(ch6$performance)
sum(is.na(ch6$motivation))/length(ch6$motivation)

# Εξετάζουμε τις εγγραφές με ελλείπουσες τιμές
ch6[is.na(ch6$performance) | is.na(ch6$motivation),]
# Πλήθος ελλειπουσών τιμών ανά εγγραφή
ch6mv<-cbind(ch6,apply(apply(ch6,1,is.na),1,sum))
names(ch6mv)[3]<-"N missing"
ch6mv[ch6mv[["N missing"]]>0,]

# Το πακέτο mice παρέχει χρήσιμες συναρτήσεις για τον έλεγχο ελλειπουσών τιμών
mice::md.pattern(ch6)

#####

## ΙΣΤΟΓΡΑΜΜΑΤΑ

# Ιστογράμματα
hist(ch6$performance)
hist(ch6$motivation)
# Εναλλακτικά, μπορούμε να απεικονίσουμε  τους πίνακες συχνοτήτων
barplot(table(ch6$performance),las=1)
barplot(table(ch6$motivation),las=1)

# Ιστογράμματα με κανονική κατανομή αναφοράς 
# Αφαιρούμε τις ελλείπουσες τιμές
p<-na.omit(ch6$performance)
# Ιστόγραμμα τιμών με τα κατάλληλα όρια
hist(p,col="grey80",breaks=(min(p)-1):max(p),las=1,ylim=c(0,45),xlab="Performance")
# Διάνυσμα 100 τιμών για τις οποίες θα υπολογίσουμε την κανονική καμπύλη ώστε να φαίνεται συνεχής και ομαλή
x<-seq(min(p)-1,max(p),length.out=100)
# Εμφάνιση της καμπύλης με κατάλληλη προσαρμογή αξόνων
lines(x,dnorm(x+0.5,mean(p),sd(p))*length(p))
# Το 0.5 μετακινεί οριζόντια την καμπύλη να συμφωνεί με το κέντρο κάθε μπάρας (αντί το σύνορο)
# Ο πολλαπλασιασμός με το πλήθος των τιμών μετατρέπει τη σχετική συχνότητα του dnorm σε αντίστοιχο πλήθος
#
# Επανάληψη για το κίνητρο
m<-na.omit(ch6$motivation)
hist(m,col="grey80",breaks=(min(m)-1):max(m),las=1,xlab="Motivation")
x<-seq(min(m)-1,max(m),length.out=100)
lines(x,dnorm(x+0.5,mean(m),sd(m))*length(m))

#####

## ΣΥΜΜΕΤΡΙΑ/ΛΟΞΟΤΗΤΑ ΚΑΙ ΚΥΡΤΩΣΗ

# Οι βασικοί τύποι
sk.p<- (sum((p-mean(p))^3)/length(p)) / ((sum((p-mean(p))^2)/length(p))^(3/2))
sk.m<- (sum((m-mean(m))^3)/length(m)) / ((sum((m-mean(m))^2)/length(m))^(3/2))
#
ku.p<- (sum((p-mean(p))^4)/length(p)) / ((sum((p-mean(p))^2)/length(p))^2) -3
ku.m<- (sum((m-mean(m))^4)/length(m)) / ((sum((m-mean(m))^2)/length(m))^2) -3

# τυπικό σφάλμα λοξότητας και κύρτωσης
Np<-length(p)
Nm<-length(m)
# from Tabachnick & Fidell (4th ed., p. 73)
se.sk.p<-sqrt(6/Np)
se.ku.p<-sqrt(24/Np)
se.sk.m<-sqrt(6/Nm)
se.ku.m<-sqrt(24/Nm)
# from Wright & Herrington (2011)
# se.sk<-sqrt((6*(N-2))/((N+1)*(N+3)))
# se.ku<-sqrt((24*N*(N-2)*(N-3))/((N+3)*(N+5)*(N+1)^2))
# from http://www.tc3.edu/instruct/sbrown/stat/shape.htm
# se.sk<-sqrt((6*N*(N-1))/((N-2)*(N+1)*(N+3)))
# se.ku<-2*se.sk*sqrt((N^2-1)/((N-3)*(N+5)))

# Οι σχετικές συναρτήσεις υπάρχουν σε διάφορα πακέτα, π.χ. το e1071
# (Οι συνηθισμένοι ορισμοί χρησιμοποιούνται με type=1, για το αποτέλεσμα του SPSS δίνουμε type=2)
e1071::skewness(p,type=1)
e1071::skewness(m,type=1)
e1071::kurtosis(p,type=1)
e1071::kurtosis(m,type=1)
# Το πακέτο psych (χρησιμοποιεί λίγο διαφορετικούς τύπους)
psych::skew(p)
psych::skew(m)
psych::kurtosi(p)
psych::kurtosi(m)

# Εναλλακτικά, από το πακέτο psych, μαζί με άλλα περιγραφικά
psych::describe(ch6)

# Τυπικές τιμές ασυμμετρίας και κύρτωσης (διαιρούμε με το αντίστοιχο τυπικό σφάλμα)
z.sk.p<-sk.p/se.sk.p
z.sk.m<-sk.m/se.sk.m
z.ku.p<-ku.p/se.ku.p
z.ku.m<-ku.m/se.ku.m

# Αντίστοιχες πιθανότητες 
2*(1-pnorm(z.sk.p))
2*(1-pnorm(z.sk.m))
2*(1-pnorm(z.ku.p))
2*(1-pnorm(z.ku.m))

# Τα όρια πιθανότητας που αναφέρονται στο βιβλίο
round(2*(1-pnorm(2.58)),2) # .01
round(2*(1-pnorm(3.29)),3) # .001
# ...μπορούν να υπολογιστούν ως εξής (διαιρούμε δια 2 για αμφίπλευρο έλεγχο):
round(qnorm(1-(0.01/2)),2)
round(qnorm(1-(0.001/2)),2)

######
 
## ΔΙΑΓΡΑΜΜΑΤΑ ΚΑΙ ΕΛΕΓΧΟΣ ΚΑΝΟΝΙΚΟΤΗΤΑΣ

# Q-Q plot
qqnorm(p)
qqline(p)
#
qqnorm(m)
qqline(m)

# Το SPSS αντιστρέφει τους άξονες, θέτοντας τις παρατηρούμενες τιμές στον οριζόντιο 
qqnorm(p,datax=T)
qqline(p,datax=T)
#
qqnorm(m,datax=T)
qqline(m,datax=T)

# «Διορθωμένο» κανονικό γράφημα
as.data.frame(qqnorm(p,datax=T,plot.it=F))->dfqp
if(nrow(dfqp)%%4 %in% c(1,3)){dfqp$y[dfqp$y==max(dfqp$y)]<-NA} # ensure that hinges equal observations
p2<-dfqp[dfqp$y %in% fivenum(dfqp$y)[c(2,4)],] # get the 1st & 3rd quartile points
slope<-(diff(p2$y)/diff(p2$x))
dfqp$detrend<-scale(dfqp$x*slope-dfqp$y,scale=F)
plot(dfqp$x,dfqp$detrend)
abline(h=0)
#
# Εναλλακτικός υπολογισμός διόρθωσης
#intercept<-p2$y[1]-p2$x[1]*slope
#dfqp$detrend<-dfqp$y-(intercept+dfqp$x*slope)

as.data.frame(qqnorm(m,datax=T,plot.it=F))->dfqm
if(nrow(dfqm)%%4 %in% c(1,3)){dfqm$y[dfqm$y==max(dfqm$y)]<-NA}
m2<-dfqm[dfqm$y %in% fivenum(dfqm$y)[c(2,4)],] # get the 1st & 3rd quartile points
slope<-(diff(m2$y)/diff(m2$x))
dfqm$detrend<-scale(dfqm$x*slope-dfqm$y,scale=F)
plot(dfqm$x,dfqm$detrend)
abline(h=0)

# Θηκογράμματα
boxplot(p)
boxplot(m)

# Στατιστικός έλεγχος κανονικότητας
# Kolmogorov-Smirnov (όχι αυτό που υπολογίζεται από το SPSS στο explore!)
ks.test(p,pnorm)
ks.test(m,pnorm)
# Lilliefors (Kolmogorov-Smirnov), από το πακέτο nortest -- αυτό είναι το κριτήριο που υπολογίζει το SPSS
nortest::lillie.test(p)
nortest::lillie.test(m)
# Shapiro-Wilks
shapiro.test(p)
shapiro.test(m)



